// 	Creating the dataset
//	  original: 26JUN18
//	  last updated: 26JAN20
********************************************************************************

global runAll = 1	// =1: run the tsfill + generate all dropout variables 
					// =0: the tsfill data + the various dropout variables
					//	   are generated already, don't regenerate it again
					// 	   saves lots of time).  
					//
					//	If ALL of the following datasets are present in  
					//	"assembly files" folder, can set runAll to 0:
							* "mep mstate - 1 - tsfilled.dta"
							* "mep mstate - 2 - collapsed, within-wave.dta"
							* "mep mstate - 2a - _all, yr windows.dta"		
clear *

**************************************
// Convienience functions for code chunks/recodes you do a bunch, to help keep things tidy

qui do "sub - _convenience functions.do"

**************************************
// First: Open spreadsheet with specific Eurobarometer deploy dates;
//		  Get this data from wide to long format for merging.
**************************************
qui do "sub - eb_countries-over-time - import.do"
	// `surv' = temp dataset for merge created from this do-file

// Specifically save for ZA merge
drop if nation1==.	// means the country isn't in the Mannheim Trend dataset
tempfile surv
save `surv', replace

**************************************
// Next: for each country, get daily within-wave dropouts.
**************************************
if($runAll==1){
	use "2 - mep - mstate ready.dta", clear
	di _N

	// Insert ZA country codes
	zaCodes, gen(nation1) cname(country)
	tab country if(nation1==.) // all the countries that joined post-2002.  Good.
		
	preserve
		drop if nation1==.
		duplicates drop nation1, force
		tempfile nat1
		save `nat1', replace
	restore


	// Toss out-of-EP stage observations
	drop if(stage==2)

	
	// Get into UoA = MEP-wave-daily
	* duplicate a row for everyone, make new fake time column,
	* then use tsfill to fill
	expand 2, gen(new)
	clonevar date = entry_min
	replace date = exit_max if(new==1)	
	replace dropout = 0 if(new==0)	// at the start of the wave, they haven't dropped out yet.

	xtset memberid date
	
	tsfill	// NOTE: The resulting file is also massive (6 GB). *********************************
			// On Stata 16.1 MP4, calculation takes ~60-120 seconds.  Expect longer on single core.
		bysort memberid (date): gegen cc = max(country_code) // fill in ccode
		replace country_code = cc if(country_code==. & cc!=.)
		drop cc

	compress
	recode dropout (.=0) // since these are all the months where no action happens, which is why they weren't in the dataset in the first place
	epSave, n("mep mstate - 1 - tsfilled")

	// Collapse
	gcollapse (sum) dropout, by(country_code date)

	// Create running dropout variables
	* wave-based dropout
	qui do "sub - w--within-wave - gen.do"				
		// Do-file outputs saved dataset in pwd: "mep mstate - 2 - collapsed, within-wave.dta"
		
	* year-based dropout
	qui do "sub - w--within-wave - gen, yr windows.do"	

		*** WARNING: this do-files takes a while to run.  *********************************
		// On Stata 16.1 MP4: ~210 minutes (3.5 hrs.).  Expect longer on single core.
			
		// Do-file outputs saved dataset in pwd: "mep mstate - 2a - _all, yr windows.dta"
}

**************************************
// Then: for each country, get between-wave dropouts.
**************************************
qui do "sub - w--between-wave - gen.do"
	// `btwn' = name of dataset created by do-file for merge
	
// Save and go	
tempfile btwn
drop if(nation1==.)
save `btwn', replace	

**************************************
// Now: get the survey dates into the ZA dataset, then get in EP data. 
**************************************
{ // start of convenience collapse bracket
// Quickly: open up collapsed data and toss missings
use "mep mstate - 2 - collapsed, within-wave.dta", clear	// generated by "sub - w--within-wave - gen.do"
drop if(nation1==.)
tempfile mep
save `mep', replace


// Open up ZA dataset and go
use "ZA3521_v2-0-1.dta", clear

// Toss non-EU countries
drop if nation1==15	// Norway
	
// Merge survey dates
merge nation1 eb using `surv', uniqusing sort nokeep keep(survSt surv surv2)
	tab nation1 eb if(_merge==1)
	rename _merge _mergeEB
	label variable _mergeEB "MERGE: EB survey dates from eb_countries-over-time.xlsx"
		// VERDICT: Merged correctly.
		
		// EB32A and 32B aren't in the countries-over-time
		// spreadsheet, so there's no messup on Stata's part there.
		// For EB29, there's also no date listed in the countries-over
		// spreadsheet for Spain.  That might be a typo, but again, that's 
		// not a Stata-induced error.

		// IMPLIC: when you check the future merges, make sure to also run a
		// 		   tab where you exclude observations where this merge var ==1.
		
		
// Add in wave info for each survey
waveGen, gen(wave) date(survSt)		
	
	
// Merge in EU join dates
* get data prepped for merge
preserve
	import excel "Accession Dates.xlsx", sheet("Sheet1") firstrow clear
	
	// Insert ZA country codes
	zaCodes, gen(nation1) cname(country)
	tab country if(nation1==.)
	drop if(nation1==.)	// will be countries that joined post-2002
	
	tempfile acc
	save `acc', replace
restore

* do the actual merge
merge nation1 using `acc', uniqusing sort nokeep keep(accDate)
rename _merge _mergeAcc
	tab nation1 if(_mergeAcc==1)	// just NI and E. Germany.  OK.
	label variable _mergeAcc "MERGE: accession dates"
	tab _mergeAcc if(_mergeEB!=1)
	
	
// Merge in dropouts [within-wave]
** wave-based windows
	* Merges in the values for one day BEFORE the survey was deployed in that country
	gen date = survSt - 1
	merge nation1 date using `mep', uniqusing sort nokeep keep(runSum_ww_curr 	 runSum_ww_prev 	runSum_ww_prevAll ///
															   runSumEP_ww_curr  runSumEP_ww_prev	runSumEP_ww_prevAll) 	 
		rename _merge _mergeDOut_ww
		label variable _mergeDOut_ww "MERGE: within-wave dropout variables from 'mep mstate - 2 - collapsed, within-wave.dta'"
		
		tab _mergeDOut_ww
		tab survSt nation1 if(_mergeDOut_ww==1 & survSt>=date("19790801", "YMD"))						// wave 1 doesn't sit until 01AUG1979.
		tab survSt nation1 if(_mergeDOut_ww==1 & survSt>=date("19790801", "YMD") & survSt>=accDate)		// how many occur after the EP starts AND after the country joins the EU.
		tab survSt nation1 if(_mergeDOut_ww==1 & _mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate)
			// None.  Good.

		
		// get the dropouts for all other countries but this one in EP
			*curr
			gen double runSumEPoth_ww_curr = runSumEP_ww_curr - runSum_ww_curr
			label variable runSumEPoth_ww_curr "DRP_ww: EP-wide running # of all dropouts this wave WITHOUT this country's MEPs"
			order runSumEPoth_ww_curr, after(runSumEP_ww_curr)
			
			*prev
			gen double runSumEPoth_ww_prev = runSumEP_ww_prev - runSum_ww_prev
			label variable runSumEPoth_ww_prev "DRP_ww: EP-wide running # of all dropouts in prev wave WITHOUT this country's MEPs"
			order runSumEPoth_ww_prev, after(runSumEP_ww_prev)
			
			*prevAll
			gen double runSumEPoth_ww_prevAll = runSumEP_ww_prevAll - runSum_ww_prevAll
			label variable runSumEPoth_ww_prevAll "DRP_ww: EP-wide running # of all dropouts in ALL prev waves WITHOUT this country's MEPs"
			order runSumEPoth_ww_prevAll, after(runSumEP_ww_prevAll)

** year-based windows
preserve
	use "mep mstate - 2a - _all, yr windows.dta", clear	// generated in "sub - w--within-wave - gen, yr windows.do"	
	
	// Insert ZA country codes
	zaCodes, gen(nation1) cname(country_code) wtd
	
	tab country if(nation1==.)
	drop if(nation1==.)	// will be countries that joined post-2002
	
	tempfile wwYrs
	save `wwYrs', replace
restore 

merge nation1 date using "`wwYrs'", ///
								uniqusing sort nokeep keep(runSum_ww_1yr runSum_ww_2yr runSumEP_ww_1yr runSumEP_ww_2yr) 	 
	
	rename _merge _mergeDOut_ww2
	label variable _mergeDOut_ww2 "MERGE: within-wave dropout variables from 'mep mstate - 2a - _all, yr windows.dta'"
	
	tab _mergeDOut_ww2
	tab survSt nation1 if(_mergeDOut_ww2==1 & survSt>=date("19790801", "YMD"))						// wave 1 doesn't sit until 01AUG1979.
	tab survSt nation1 if(_mergeDOut_ww2==1 & survSt>=date("19790801", "YMD") & survSt>=accDate)		// how many occur after the EP starts AND after the country joins the EU.
	tab survSt nation1 if(_mergeDOut_ww2==1 & _mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate)
	tab survSt nation1 if(_mergeDOut_ww2==1 & _mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt<=date("20140601", "YMD") & survSt>=accDate)
	
	// get the dropouts for all other countries but this one in EP
		* 1 yr
		gen double runSumEPoth_ww_1yr = runSumEP_ww_1yr - runSum_ww_1yr
		label variable runSumEPoth_ww_1yr "DRP_ww: EP-wide running # of all dropouts in last year WITHOUT this country's MEPs"
		order runSumEPoth_ww_curr, after(runSumEP_ww_2yr)
			
		* 2 yr
		gen double runSumEPoth_ww_2yr = runSumEP_ww_2yr - runSum_ww_2yr
		label variable runSumEPoth_ww_2yr "DRP_ww: EP-wide running # of all dropouts in last two years WITHOUT this country's MEPs"
		order runSumEPoth_ww_2yr, after(runSumEPoth_ww_1yr)
		
	// Incorporate EP-level country-level weighted denominator
	qui do "sub - funct, weighted EP wave dates.do"
	qui levelsof date, local(dates)
	ctrySeats 	// to get the Mata matrix w/country-specific seats in memory -> stored in "ctrySeats"

	* loop over window sizes
	forvalues y = 1/2{
		// generate the holder variables
		gen double seatsEP_`y'yr = .
			label variable seatsEP_`y'yr "SEATS: weighted overall # of EP seats, `y' yr. window"
		gen double seatsEPoth_`y'yr = .
			label variable seatsEPoth_`y'yr "SEATS: weighted overall # of EP seats WITHOUT this country, `y' yr. window"
		gen double seatTotal_`y'yr = .
			label variable seatTotal_`y'yr "SEATS: weighted # of country's EP seats, `y' yr. window"
		
		foreach d of local dates{
			epDateW, date("`d'") yrs(`y')
				mata: wvPcts = st_matrix("r(wvPcts)")
				mata: allSeats = st_matrix("r(epStAll)")	// not the most efficient, but meh.
			local epSeatLvl = `r(seats)'
			qui replace seatsEP_`y'yr = `epSeatLvl' if(date==`d')
			
			
			// get how many countries have this start date
			qui levelsof nation1 if(date==`d'), local(ccodeWinners)
			
			// loop through for the country-specific weighted denominator  + all-but-this-country denominator
			foreach cw of local ccodeWinners{
				// see how many rows this country has in the ccodeWinners list for this specific `d' value
				mata: st_local("rows", strofreal(rows(select(ctrySeats, ctrySeats[,1]:==`cw'))))
				
				// if it has rows, it will have 7, based on how the ctrySeats data is inputted.
				
				// multiply the weights from epDateW.
				if(`rows'!=0){
					// subset pertaining to this country
					mata: ctrySub_sts = select(ctrySeats, ctrySeats[,1]:==`cw')[,3]		
					
					// difference between # of non-zero pct rows & # of non-zero seat rows
					mata: wvCheck = rows(select(wvPcts, wvPcts:!=0)) :== ///					// # of non-zero pct rows
									rows(select(ctrySub_sts, ctrySub_sts:!=0 :& wvPcts:!=0))  	// # of non-zero seat rows, for rows with non-zero pcts
					mata: st_local("wvCheck", strofreal(wvCheck))
					
					// >> COUNTRY-SPECIFIC
					// For all waves with non-zero values, if there are all non-zero values for seats, simple weighted multiplication
					if(`wvCheck'==1){
						mata: sts = wvPcts' * ctrySub_sts 
					}
					
					// If there are some 0 values, means this country wasn't an EU member in prev wave.  Reallocate weights to 100% of current wave.
					** PREMISED ON MAX OF TWO YEARS FOR WINDOW.  WILL NEED TO RECODE TO BE MORE GENERALIZABLE, SHOULD YOU EVER RUN LONGER WINDOWS.
					else{
						mata: sts = select(ctrySub_sts, ctrySub_sts:!=0 :& wvPcts:!=0) 	// will only return one row, given the two-year max window (leading to warning in comment above)
						mata: if(rows(sts)==0)	sts = 0;;								// NOT A TYPO.  The double semi-colon's the way to get this to work.
					}
					
					// Throw back to Stata
					mata: st_local("seatCtry", strofreal(sts))
					
					
					// >> ALL-BUT-THIS-COUNTRY-SPECIFIC (the if/else condition you check above is irrelevant for this; same logic as overall EP denominator, only w/this country's seats subtracted)
					mata: stsOth = wvPcts' * (allSeats - ctrySub_sts)
					mata: st_local("seatOth", strofreal(stsOth))
				
				}
				// if it has no rows, set seatCtry equal to 0; EP denom will be equal to the value returned earlier by epDateW
				else{
					local seatCtry = `rows'
					local seatOth = `epSeatLvl'
				}

				qui replace seatTotal_`y'yr  = `seatCtry' if(nation1==`cw' & date==`d')
				qui replace seatsEPoth_`y'yr = `seatOth'  if(nation1==`cw' & date==`d')
			}
		}
	}
	drop date
		
	
// Merge in dropouts [between-wave]
merge nation1 wave using `btwn', uniqusing sort nokeep keep(runSum_bw_prev    runSum_bw_prevAll ///
															runSumEP_bw_prev  runSumEP_bw_prevAll ///
															seatTotal     seatsEP ///
															seats_prev 	  seatsEP_prev ///
															seats_prevAll seatsEP_prevAll)	
	rename _merge _mergeDOut_bw
	
	tab _mergeDOut_bw if(survSt>=date("19790801", "YMD"))						// wave 1 doesn't sit until 01AUG1979.
	tab _mergeDOut_bw if(survSt>=date("19790801", "YMD") & survSt>=accDate)		// how many occur after the EP starts AND after the country joins the EU.
	tab _mergeDOut_bw if(_mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate)

	
// Merge in the other relevant variables for each country
* Do it as of the start of the most recent EP wave (because
* a bunch of this stuff doesn't vary within wave, and I'm
* therefore not about to go nuts getting country-year data).		
	
	* prep by getting UoA = ZA code-wave
	preserve
		use "2 - mep - mstate ready.dta", clear
		
		// keep 1 observation for every country-wave
		duplicates drop country_code wave, force
		
		// Insert ZA country codes
		zaCodes, gen(nation1) cname(country)
		drop if(nation1==.)	
			
		tempfile cLvl
		save `cLvl', replace
	restore

	
	* do the actual merge: main dataset
	merge nation1 wave using `cLvl', uniqusing sort nokeep keep(ccode ///
																dpi_state dp_1 dp_2 dp_3 ///
																lijp norris_federalism ///
																sysEP sysCPL_EP sysOpen_EP sysOrd_EP sysSMP_EP sysSTV_EP ///
																sysNat sysCPL_Nat sysMixed_Nat sysOpen_Nat sysOrd_Nat sysSTV_Nat sysSMP_Nat ///
																periph BXLdistance ///
																daysLastElect ciep daysLastElect_norm)
	rename _merge _mergeCLvl
	label variable _mergeCLvl "MERGE: country-level variables, EP1 replic main data"
	tab _mergeCLvl if(survSt>=date("19790801", "YMD") & survSt>=accDate)
	tab _mergeCLvl if(_mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate)


	* additional merge: Seki and Williams (from QoG)
	preserve
		tempfile qog

		use "QoG_t_s_v6Apr11 [standard], v0 (original).dta", clear
		drop ccode
		rename ccodecow ccode
		
		// 	There are some ccode-year pairings that aren't unique.  However, none 
		//	of them are EU countries, so just drop the duplicates and move on.
		
		duplicates drop ccode year, force
		
		save `qog', replace
	restore

	rename year ebYear
	gen year = year(survSt)
	merge ccode year using `qog', uniqusing sort nokeep keep(dpi_pr jw_persr) nol nonotes

	replace jw_persr = -jw_persr
	qui sum jw_persr, detail
	gen jw_persr_d = jw_persr > `r(p50)'
		label variable jw_persr_d "jw_persr > `r(p50)'"
		
	drop year
	rename ebYear year
	
	rename _merge _mergeQoG
	label variable _mergeQoG "MERGE: QoG dataset (Seki and Williams vars)"
	tab _mergeQoG if(survSt>=date("19790801", "YMD") & survSt>=accDate)
	tab _mergeQoG if(_mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate)

	
// Now that # seats are in: get percentages for dropout

	// WW: current: just divide by number of seats in current wave
	genD runSum_ww_currPerc   = runSum_ww_curr/seatTotal * 100
	genD runSumEP_ww_currPerc = runSumEP_ww_curr/seatsEP * 100
	genD runSumEPoth_ww_currPerc = runSumEPoth_ww_curr/(seatsEP-seatTotal) * 100

	// Can loop the rest
	foreach w in "bw" "ww"{
		* prev
		genD runSum_`w'_prevPerc   = runSum_`w'_prev/seats_prev * 100
		genD runSumEP_`w'_prevPerc = runSumEP_`w'_prev/seatsEP_prev * 100
		if("`w'"=="ww")	genD runSumEPoth_`w'_prevPerc = runSumEPoth_`w'_prev/(seatsEP_prev-seats_prev) * 100
		
		* prevAll
		genD runSum_`w'_prevAllPerc   = runSum_`w'_prevAll/seats_prevAll * 100
		genD runSumEP_`w'_prevAllPerc = runSumEP_`w'_prevAll/seatsEP_prevAll * 100
		if("`w'"=="ww")	genD runSumEPoth_`w'_prevAllPerc = runSumEPoth_`w'_prevAll/(seatsEP_prevAll-seats_prevAll) * 100
		
		if("`w'"=="ww"){
			* loop over 1yr/2yr
			forvalues y=1/2{
				genD runSum_`w'_`y'yrPerc = runSum_`w'_`y'yr/seatTotal_`y'yr * 100
				genD runSumEP_`w'_`y'yrPerc = runSumEP_`w'_`y'yr/seatsEP_`y'yr * 100
				genD runSumEPoth_`w'_`y'yrPerc = runSumEPoth_`w'_`y'yr/seatsEPoth_`y'yr * 100
			}
		}
	}
	
	
// Get number of respondents for all the relevant EP questions, generate percentages
foreach x of local epVarlist{
	// Find which value corresponds to inapp, for this variable
	local labName: value label `x'
	qui levelsof `x', local(levels)
	
	foreach l of local levels{
		// Is this value's label = "inap"?
		local label: label `labName' `l'
		
		// YES: record and break
		if("`label'"=="inap"){	
			local inapVal = `l'
			continue, break
		}
		// NO: keep searching
	}
	recode `x' (`inapVal' = .)
	
	cap drop `ones'
	tempvar ones
	gen `ones' = `x'<.
	bysort eb (nation1): egen `x'_nResp = total(`ones')
	label variable `x'_nResp "RESP: in this EB, # of non-inap respondants for `x'"
	
}

	
// Merge in EP election turnout
preserve
	use "turnout - _all.dta", clear
	
	zaCodes, gen(nation1) cn(country)
	drop if(nation1==.) // all the more recent entrants.  Excellent.
	
	gen double year1 = mdy(1, 1, year+1) //(+1 so that we'll get the correct election date for the *current* wave, by putting the fake date smack in the middle of the current wave's date range)
	waveGen, gen(wave) date(year1)
	
	// Dates from 2018 Daniel and Metzger JLS paper
	** NOTE: not country specific
		gen wave_elMin = .
		format wave_elMin %td
		label variable wave_elMin `"Earliest EP election date for this wave (dates vary by country)"'
		
	* Wave 1:
	local wv = 1
		replace wave_elMin = date("19790607", "YMD") if(wave==`wv')	
		
	* Wave 2:
	local wv = 2
		replace wave_elMin = date("19840614", "YMD") if(wave==`wv')
		
	* Wave 3:
	local wv = 3
		replace wave_elMin = date("19890615", "YMD") if(wave==`wv')
		
	* Wave 4:
	local wv = 4
		replace wave_elMin = date("19940609", "YMD") if(wave==`wv')
		
	* Wave 5:
	local wv = 5
		replace wave_elMin = date("19990610", "YMD") if(wave==`wv')
		
	* Wave 6:
	local wv = 6
		replace wave_elMin = date("20040610", "YMD") if(wave==`wv')
		
	* Wave 7:
	local wv = 7
		replace wave_elMin = date("20090604", "YMD") if(wave==`wv')		
		
	* Wave 8:
	local wv = 8
		replace wave_elMin = date("20140522", "YMD") if(wave==`wv')	
	
	rename wave_elMin elecEP
	tempfile turnout
	save `turnout', replace
restore

** define turnout in terms of turnout for most recent EP election
merge nation1 wave using `turnout', sort uniqusing nokeep keep(voterturnout registration vapturnout votingagepopulation population elecEP)
rename _merge _mergeIDEA
tab _mergeIDEA
	label variable _mergeIDEA "MERGE: turnout/EP elec variables, source: IDEA"
	tab _mergeIDEA if(survSt>=date("19790801", "YMD") & survSt>=accDate)
	tab _mergeIDEA if(_mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate)

	labPre voterturnout-population, stub(IDEA)
	
genD daysLastElectEP = survSt - elecEP, ///
	label(Days since last EP election @ survSt)

// Are there any situations in which the survey's given before the EP election occurs in a year?
count if(_mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate & survSt<elecEP)	
	// None.  Good.  That's how it should be, given that I wrote in the merge IDs as waves, not years, but famous last words.
	

// National election: when was the last one?
// * Store the election dates in a country-specific local.  Then, cycle through 
// * the dates.  When you finally find a date that's greater than survSt, you 
// * know the *previous* date in the list was the most recent election.
	
	preserve
		use "Turnover - Election Dates.dta", clear
		
		zaCodes, gen(nation1) cn(country)
		drop if(nation1==.) // all the more recent entrants.  Excellent.

		qui levelsof nation1, local(ccs)
		foreach c of local ccs{
			qui levelsof election if(nation1==`c'), local("`c'")
		}
	restore	

	// Get the nation1 list in this dataset
	gen double elecNatl = .
	format elecNatl %td
	
	qui levelsof nation1, local(ccs)
	foreach c of local ccs{			// by each country
		foreach el of local `c'{	// for each election date in the country's list
			if("`el' `ferest()'"!="``c''"){	// if this isn't the first one in the loop
				replace elecNatl = `incumb' if(nation1==`c' & survSt<`el' & survSt>`incumb')
			}
			
			local incumb = `el'
			replace elecNatl = `incumb' if(nation1==`c' & survSt>`incumb') 
		}
	}
	// check the missings
	count if(elecNatl==. & _mergeEB!=1 & survSt>=date("19790801", "YMD") & survSt>=accDate)
		// Good: nothing's missing that shouldn't be
		
	// Gen the final national election vars.	
	cap drop daysLastElect daysLastElect_norm
	genD daysLastElect = survSt-elecNatl, ///
		label(Days since last national election @ survSt)
	genD daysLastElect_norm = daysLastElect/(ciep*365.25) * 100
		** ciep is in years.  Must convert into days.


// Average number of citizens represented by each MEP
genD mepPerCitz = votingagepopulation/seatTotal

	
// How long has the respondent's country been in the EU, in years?
genD ageEU = (survSt - accDate)/365.25, ///
	label(Length of country's MS in EU, in years)
	
	
// Clean up individual-level variables
recode age (0=.)

recode sex (8=.)
replace sex = sex-1
rename sex female	// to make the name more informative
	label define SEX 1 "female" 0 "male" , replace

recode lrs (99=.)
clonevar lrsAnsw = lrs	// for people that answered this Q, for a moment.
	recode lrsAnsw (98=.)
	recode lrsAnsw (96=.r)
	
* for education, go into bins, similar to educrec. (diff betwn
* educ and educrec is the wording of "finished schooling" vs. "stopped"
* BUT: for people still studying, use their current age.
gen educ2 = .
	* done studying
	replace educ2 = 1 if((educ==1 | educ==2) | educrec==1)	// 1: up to 15 (incl.)
	replace educ2 = 2 if((educ>=3 & educ<=6) | educrec==2)	// 2: 16-19
	replace educ2 = 3 if((educ>=7 & educ<=9) | educrec==3)	// 3: 20+
	
	* still studying
	replace educ2 = 1 if((educ==10 | educrec==4) & age<=15)			 // 1: up to 15 (incl.)
	replace educ2 = 2 if((educ==10 | educrec==4) & age>15 & age<=19) // 2: 16-19
	replace educ2 = 3 if((educ==10 | educrec==4) & age>19 & age<.)	 // 3: 20+
	
	* deal with DK/NAs
	replace educ2 = -9 if(educ==98)
		
	label var educ2 "Combo of educ + educrec, w/age subbed in for still studying"
	tab educ2, gen(ed2_)
	
* bin community (if they answer)
tab typecmty, gen(usr_)
			
* participation
	// DK/NA as missing, recode and shift so that "depends" is in middle
	recode particip (8=.) (9=.r)
	recode particip (5=7) (3=4) (4=5)
	recode particip (7=3)
	
	label define PARTICIP 1 "CERTAINLY YES" 2 "PROBABLY YES" 4 "PROBABLY NOT" 5 "CERTAINLY NOT" 3 "depends" , replace

* political interests
recode polint  (8=.) (9=.r)

* efficacy
recode efficacy (8=.)

* national vs. EU
recode feel (8=.) (9=.r)
tab feel, gen(ident_)
	
* Euroskeptic Q
recode membrshp (8=.) (9=.r)	
		
* Euro MS Q
recode citizen (0 8 = .)
	
* Benefit
recode benefit (8 9 = .) (2 = 0)
	
// All the merge tabs look good.  Proceed.
compress	
cd "$dir"
cd ..
epSave, n("1 - compiled ZA file, v2")		
}
*